@@ -1,4 +1,4 @@
-//@line 39 "/mnt/data/212/toolkit/components/viewsource/content/viewSource.js"
+//@line 39 "/home/gscrivano/icecat/301/toolkit/components/viewsource/content/viewSource.js"
 
 const pageLoaderIface = Components.interfaces.nsIWebPageDescriptor;
 const nsISelectionPrivate = Components.interfaces.nsISelectionPrivate;
@@ -31,12 +31,6 @@ function onLoadViewSource()
 {
   viewSource(window.arguments[0]);
   document.commandDispatcher.focusedWindow = content;
-  gFindBar.initFindBar();
-}
-
-function onUnloadViewSource()
-{
-  gFindBar.uninitFindBar();
 }
 
 function getBrowser()
@@ -77,12 +71,14 @@ function viewSource(url)
   //    arg[1] - Charset value in the form 'charset=xxx'.
   //    arg[2] - Page descriptor used to load content from the cache.
   //    arg[3] - Line number to go to.
+  //    arg[4] - Whether charset was forced by the user
   //
   if ("arguments" in window) {
     var arg;
     //
     // Set the charset of the viewsource window...
     //
+    var charset;
     if (window.arguments.length >= 2) {
       arg = window.arguments[1];
 
@@ -91,8 +87,23 @@ function viewSource(url)
           var arrayArgComponents = arg.split('=');
           if (arrayArgComponents) {
             //we should "inherit" the charset menu setting in a new window
-            getMarkupDocumentViewer().defaultCharacterSet = arrayArgComponents[1];
-          } 
+            charset = arrayArgComponents[1];
+            gBrowser.markupDocumentViewer.defaultCharacterSet = charset;
+          }
+        }
+      } catch (ex) {
+        // Ignore the failure and keep processing arguments...
+      }
+    }
+    // If the document had a forced charset, set it here also
+    if (window.arguments.length >= 5) {
+      arg = window.arguments[4];
+
+      try {
+        if (arg === true) {
+          var docCharset = getBrowser().docShell.QueryInterface
+                             (Components.interfaces.nsIDocCharset);
+          docCharset.charset = charset;
         }
       } catch (ex) {
         // Ignore the failure and keep processing arguments...
@@ -133,12 +144,16 @@ function viewSource(url)
   }
 
   if (loadFromURL) {
+    // We need to set up session history to give us a page descriptor.
+    //
+    var webNavigation = getBrowser().webNavigation;
+    webNavigation.sessionHistory = Components.classes["@mozilla.org/browser/shistory;1"].createInstance();
     //
     // Currently, an exception is thrown if the URL load fails...
     //
     var loadFlags = Components.interfaces.nsIWebNavigation.LOAD_FLAGS_NONE;
     var viewSrcUrl = "view-source:" + url;
-    getBrowser().webNavigation.loadURI(viewSrcUrl, loadFlags, null, null, null);
+    webNavigation.loadURI(viewSrcUrl, loadFlags, null, null, null);
   }
 
   //check the view_source.wrap_long_lines pref and set the menuitem's checked attribute accordingly
@@ -224,6 +239,25 @@ function onExitPP()
   toolbox.hidden = false;
 }
 
+function getPPBrowser()
+{
+  return document.getElementById("content");
+}
+
+function getNavToolbox()
+{
+  return document.getElementById("appcontent");
+}
+
+function getWebNavigation()
+{
+  try {
+    return gBrowser.webNavigation;
+  } catch (e) {
+    return null;
+  }
+}
+
 function ViewSourceGoToLine()
 {
   var promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
@@ -332,7 +366,6 @@ function goToLine(line)
 
   var selCon = getSelectionController();
   selCon.setDisplaySelection(nsISelectionController.SELECTION_ON);
-  selCon.setCaretEnabled(true);
   selCon.setCaretVisibilityDuringSelection(true);
 
   // Scroll the beginning of the line into view.
@@ -367,7 +400,6 @@ function updateStatusBar()
 
   var selCon = getSelectionController();
   selCon.setDisplaySelection(nsISelectionController.SELECTION_ON);
-  selCon.setCaretEnabled(true);
   selCon.setCaretVisibilityDuringSelection(true);
 
   var interlinePosition = selection
@@ -562,8 +594,3 @@ function BrowserSetForcedDetector(doReload)
     PageLoader.loadPage(PageLoader.currentDescriptor, pageLoaderIface.DISPLAY_NORMAL);
   }
 }
-
-function getMarkupDocumentViewer()
-{
-  return gBrowser.markupDocumentViewer;
-}
